@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Scanner/RCTests.py 5134 2010/08/16 23:02:40 bdeegan"
+__revision__ = "src/engine/SCons/Scanner/RCTests.py 5357 2011/09/09 21:31:03 bdeegan"
 
 import TestCmd
 import SCons.Scanner.RC
@@ -57,6 +57,7 @@ TEST_D3DFX   D3DFX DISCARDABLE "testEffect.fx"
 
 """)
 
+test.write('t3.rc','#include "t1.h"\r\n')
 
 # Create dummy include files
 headers = ['t1.h',
@@ -144,12 +145,22 @@ class RCScannerTestCase2(unittest.TestCase):
                    'testregis.rgs','testtypelib.tlb']
         deps_match(self, deps, headers)
 
+class RCScannerTestCase3(unittest.TestCase):
+    def runTest(self):
+        path = []
+        env = DummyEnvironment(RCSUFFIXES=['.rc','.rc2'],
+                               CPPPATH=path)
+        s = SCons.Scanner.RC.RCScan()
+        deps = s(env.File('t3.rc'), env, path)
+        headers = ['t1.h']
+        deps_match(self, deps, headers)
         
 
 def suite():
     suite = unittest.TestSuite()
     suite.addTest(RCScannerTestCase1())
     suite.addTest(RCScannerTestCase2())
+    suite.addTest(RCScannerTestCase3())
     return suite
 
 if __name__ == "__main__":
