@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/SubstTests.py 5134 2010/08/16 23:02:40 bdeegan"
+__revision__ = "src/engine/SCons/SubstTests.py 5357 2011/09/09 21:31:03 bdeegan"
 
 import SCons.compat
 
@@ -550,8 +550,10 @@ class scons_subst_TestCase(SubstTestCase):
             expect = [
                 # Python 2.3, 2.4
                 "TypeError `unsubscriptable object' trying to evaluate `${NONE[2]}'",
-                # Python 2.5 and later
+                # Python 2.5, 2.6
                 "TypeError `'NoneType' object is unsubscriptable' trying to evaluate `${NONE[2]}'",
+                # Python 2.7 and later
+                "TypeError `'NoneType' object is not subscriptable' trying to evaluate `${NONE[2]}'",
             ]
             assert str(e) in expect, e
         else:
