@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/UtilTests.py 5134 2010/08/16 23:02:40 bdeegan"
+__revision__ = "src/engine/SCons/UtilTests.py 5357 2011/09/09 21:31:03 bdeegan"
 
 import SCons.compat
 
@@ -668,7 +668,7 @@ class UtilTestCase(unittest.TestCase):
 
     def test_LogicalLines(self):
         """Test the LogicalLines class"""
-        fobj = io.StringIO(r"""
+        content = r"""
 foo \
 bar \
 baz
@@ -676,7 +676,12 @@ foo
 bling \
 bling \ bling
 bling
-""")
+"""
+        try:
+            fobj = io.StringIO(content)
+        except TypeError:
+            # Python 2.7 and beyond require unicode strings.
+            fobj = io.StringIO(unicode(content))
 
         lines = LogicalLines(fobj).readlines()
         assert lines == [
