@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -22,7 +22,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/test_strings.py 5134 2010/08/16 23:02:40 bdeegan"
+__revision__ = "src/test_strings.py 5357 2011/09/09 21:31:03 bdeegan"
 
 """
 Verify that we have proper strings like Copyright notices on all the
@@ -106,8 +106,8 @@ class Checker(object):
 
 class CheckUnexpandedStrings(Checker):
     expressions = [
-        re.compile('Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation'),
-        re.compile('src/test_strings.py 5134 2010/08/16 23:02:40 bdeegan'),
+        re.compile('Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 The SCons Foundation'),
+        re.compile('src/test_strings.py 5357 2011/09/09 21:31:03 bdeegan'),
     ]
     def must_be_built(self):
         return None
@@ -228,8 +228,10 @@ check_list = [
             'src/script/setup.cfg',
             'test/Fortran/.exclude_tests',
             'timings/changelog.html',
+            'timings/ElectricCloud/genscons.pl',
             'timings/graph.html',
             'timings/index.html',
+            'review.py',
         ],
         remove_patterns = [
             '*.js',
